@@ -1,2 +1,3 @@
 // if libgrio has no sources, it doesn't get built correctly
-int gr_bug_work_around_6;
+
+static int gr_bug_work_around_6;
