@@ -20,6 +20,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <gr_complex.h>
 #include "gr_fir_scc_simd.h"
 #include "complex_dotprod_generic.h"
