@@ -24,21 +24,23 @@ from build_utils import output_glue
 
 import generate_gr_fir_filter_XXX
 import generate_gr_interp_fir_filter_XXX
+import generate_gr_rational_resampler_base_XXX
 import generate_gr_freq_xlating_fir_filter_XXX
 import generate_gr_fir_sysconfig_generic
 import generate_gr_fir_sysconfig
 import generate_gr_fir_util
 import generate_gr_fir_XXX
 
-def generate_all ():
-    generate_gr_fir_XXX.generate ()
-    generate_gr_fir_filter_XXX.generate ()
-    generate_gr_interp_fir_filter_XXX.generate ()
-    generate_gr_freq_xlating_fir_filter_XXX.generate ()
-    generate_gr_fir_sysconfig_generic.generate ()
-    generate_gr_fir_sysconfig.generate ()
-    generate_gr_fir_util.generate ()
-    output_glue ('filter')
+def generate_all():
+    generate_gr_fir_XXX.generate()
+    generate_gr_fir_filter_XXX.generate()
+    generate_gr_interp_fir_filter_XXX.generate()
+    generate_gr_rational_resampler_base_XXX.generate()
+    generate_gr_freq_xlating_fir_filter_XXX.generate()
+    generate_gr_fir_sysconfig_generic.generate()
+    generate_gr_fir_sysconfig.generate()
+    generate_gr_fir_util.generate()
+    output_glue('filter')
 
 if __name__ == '__main__':
-    generate_all ()
+    generate_all()
