@@ -26,6 +26,8 @@
 #include <gr_block.h>
 #include <assert.h>
 
+//#define	DEBUG_SIMPLE_CORRELATOR
+
 class gr_simple_correlator;
 typedef boost::shared_ptr<gr_simple_correlator> gr_simple_correlator_sptr;
 
@@ -34,8 +36,6 @@ gr_simple_correlator_sptr gr_make_simple_correlator (int payload_bytesize);
 /*!
  * \brief inverse of gr_simple_framer (more or less)
  * \ingroup block
- *
- * TAPR DCC-2004 demo...
  */
 class gr_simple_correlator : public gr_block
 {
@@ -47,14 +47,32 @@ class gr_simple_correlator : public gr_block
   unsigned int	 d_osi;				// over sample index [0,OVERSAMPLE-1]
   unsigned int	 d_transition_osi;		// first index where Hamming dist < thresh
   unsigned int	 d_center_osi;			// center of bit
-  unsigned int	 d_shift_reg[OVERSAMPLE];
+  unsigned long long int d_shift_reg[OVERSAMPLE];
   int		 d_bblen;			// length of bitbuf
   unsigned char	*d_bitbuf;			// demodulated bits
   int		 d_bbi;				// bitbuf index
 
+  static const int AVG_PERIOD = 512;		// must be power of 2 (for freq offset correction)
+  int	d_avbi;
+  float	d_avgbuf[AVG_PERIOD];
+  float d_avg;
+  float d_accum;
+
+#ifdef DEBUG_SIMPLE_CORRELATOR
+  FILE		*d_debug_fp;			// binary log file
+#endif
+
   friend gr_simple_correlator_sptr gr_make_simple_correlator (int payload_bytesize);
   gr_simple_correlator (int payload_bytesize);
 
+
+  inline int slice (float x)
+  {
+    return x >= d_avg ? 1 : 0;
+  }
+
+  void update_avg(float x);
+
   void enter_locked ();
   void enter_under_threshold ();
   void enter_looking ();
