@@ -40,7 +40,7 @@ gr_sync_block::forecast (int noutput_items, gr_vector_int &ninput_items_required
 {
   unsigned ninputs = ninput_items_required.size();
   for (unsigned i = 0; i < ninputs; i++)
-    ninput_items_required[i] = noutput_items + history() - 1;
+    ninput_items_required[i] = fixed_rate_noutput_to_ninput (noutput_items);
 }
 
 int
