@@ -30,6 +30,7 @@
 #include <qa_gr_circular_file.h>
 #include <qa_gr_fxpt.h>
 #include <qa_gr_fxpt_nco.h>
+#include <qa_gr_fxpt_vco.h>
 
 CppUnit::TestSuite *
 qa_general::suite ()
@@ -40,6 +41,7 @@ qa_general::suite ()
   s->addTest (qa_gr_circular_file::suite ());
   s->addTest (qa_gr_fxpt::suite ());
   s->addTest (qa_gr_fxpt_nco::suite ());
+  s->addTest (qa_gr_fxpt_vco::suite ());
   
   return s;
 }
