@@ -24,11 +24,12 @@
 #define INCLUDED_GR_FILE_SINK_H
 
 #include <gr_sync_block.h>
+#include <omnithread.h>
 
 class gr_file_sink;
 typedef boost::shared_ptr<gr_file_sink> gr_file_sink_sptr;
 
-gr_file_sink_sptr gr_make_file_sink (size_t itemsize, const char *filename);
+gr_file_sink_sptr gr_make_file_sink(size_t itemsize, const char *filename);
 
 /*!
  * \brief Write stream to file.
@@ -37,21 +38,37 @@ gr_file_sink_sptr gr_make_file_sink (size_t itemsize, const char *filename);
 
 class gr_file_sink : public gr_sync_block
 {
-  friend gr_file_sink_sptr gr_make_file_sink (size_t itemsize, const char *filename);
+  friend gr_file_sink_sptr gr_make_file_sink(size_t itemsize, const char *filename);
 
  private:
   size_t	d_itemsize;
-  void	       *d_fp;
+  void	       *d_fp;		// current FILE pointer
+  void	       *d_new_fp;	// new FILE pointer
+  bool		d_updated;	// is there a new FILE pointer?
+  omni_mutex	d_mutex;
 
  protected:
-  gr_file_sink (size_t itemsize, const char *filename);
+  gr_file_sink(size_t itemsize, const char *filename);
 
  public:
-  ~gr_file_sink ();
+  ~gr_file_sink();
 
-  int work (int noutput_items,
-	    gr_vector_const_void_star &input_items,
-	    gr_vector_void_star &output_items);
+  /*! 
+   * \brief Open filename and begin output to it.
+   */
+  bool open(const char *filename);
+
+  /*!
+   * \brief Close current output file.
+   *
+   * Closes current output file and ignores any output until
+   * open is called to connect to another file.
+   */
+  void close();
+
+  int work(int noutput_items,
+	   gr_vector_const_void_star &input_items,
+	   gr_vector_void_star &output_items);
 };
 
 
