@@ -1,6 +1,7 @@
 //				Package : omnithread
 // omnithread/nt.cc		Created : 6/95 tjr
 //
+//    Copyright (C) 2006 Free Software Foundation, Inc.
 //    Copyright (C) 1995-1999 AT&T Laboratories Cambridge
 //
 //    This file is part of the omnithread library
@@ -332,9 +333,12 @@ omni_condition::broadcast(void)
 #define SEMAPHORE_MAX 0x7fffffff
 
 
-omni_semaphore::omni_semaphore(unsigned int initial)
+omni_semaphore::omni_semaphore(unsigned int initial, unsigned int max_count)
 {
-    nt_sem = CreateSemaphore(NULL, initial, SEMAPHORE_MAX, NULL);
+    if (max_count > SEMAPHORE_MAX)
+      max_count= SEMAPHORE_MAX;
+
+    nt_sem = CreateSemaphore(NULL, initial, max_count, NULL);
 
     if (nt_sem == NULL) {
       DB( cerr << "omni_semaphore::omni_semaphore: CreateSemaphore error "
