@@ -1,6 +1,7 @@
 //				Package : omnithread
 // omnithread/posix.cc		Created : 7/94 tjr
 //
+//    Copyright (C) 2006 Free Software Foundation, Inc.
 //    Copyright (C) 1994-1999 AT&T Laboratories Cambridge
 //
 //    This file is part of the omnithread library
@@ -190,14 +191,17 @@ omni_condition::broadcast(void)
 
 ///////////////////////////////////////////////////////////////////////////
 //
-// Counting semaphore
+// Counting (or binary) semaphore
 //
 ///////////////////////////////////////////////////////////////////////////
 
 
-omni_semaphore::omni_semaphore(unsigned int initial) : c(&m)
+omni_semaphore::omni_semaphore(unsigned int initial, unsigned int _max_count) : c(&m)
 {
     value = initial;
+    max_count = _max_count;
+    if (value < 0 || max_count < 1)
+      throw omni_thread_fatal(0);
 }
 
 omni_semaphore::~omni_semaphore(void)
@@ -232,7 +236,8 @@ omni_semaphore::post(void)
 {
     {
         omni_mutex_lock l(m);
-        value++;
+	if (value < max_count)
+	  value++;
     }
 
     c.signal();
