@@ -20,6 +20,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <qa_gr_buffer.h>
 #include <gr_buffer.h>
 #include <cppunit/TestAssert.h>
