@@ -38,18 +38,28 @@ class gr_add_const_ss;
 class gr_add_ff;
 class gr_add_ii;
 class gr_add_ss;
+class gr_agc_cc;
+class gr_agc_ff;
+class gr_align_on_samplenumbers_ss;
 class gr_base_error_handler;
 class gr_block;
 class gr_bytes_to_syms;
+class gr_char_to_float;
 class gr_check_counting_s;
 class gr_check_lfsr_32k_s;
+class gr_chunks_to_symbols_bc;
+class gr_chunks_to_symbols_bf;
+class gr_clock_recovery_mm_cc;
 class gr_clock_recovery_mm_ff;
 class gr_complex_to_arg;
 class gr_complex_to_float;
 class gr_complex_to_imag;
+class gr_complex_to_interleaved_short;
 class gr_complex_to_mag;
 class gr_complex_to_real;
 class gr_conjugate_cc;
+class gr_costas_loop_cc;
+class gr_dd_mpsk_sync_cc;
 class gr_deinterleave;
 class gr_divide_cc;
 class gr_divide_ff;
@@ -97,7 +107,9 @@ class gr_interp_fir_filter_fff;
 class gr_interp_fir_filter_fsf;
 class gr_interp_fir_filter_scc;
 class gr_keep_one_in_n;
+class gr_kludge_copy;
 class gr_lfsr_32k_source_s;
+class gr_lms_dfe_cc;
 class gr_lms_dfe_ff;
 class gr_message_sink;
 class gr_message_source;
@@ -125,8 +137,10 @@ class gr_null_sink;
 class gr_null_source;
 class gr_oscope_sink_f;
 class gr_oscope_sink_x;
+class gr_pa_2x2_phase_combiner;
+class gr_packed_to_unpacked_bb;
 class gr_packet_sink;
-class gr_parallel_to_serial;
+class gr_phase_modulator_fc;
 class gr_pll_carriertracking_cc;
 class gr_pll_freqdet_cf;
 class gr_pll_refout_cc;
@@ -142,7 +156,6 @@ class gr_rational_resampler_base_fsf;
 class gr_rational_resampler_base_scc;
 class gr_rms_cf;
 class gr_rms_ff;
-class gr_serial_to_parallel;
 class gr_short_to_float;
 class gr_sig_source_c;
 class gr_sig_source_f;
@@ -151,8 +164,11 @@ class gr_sig_source_s;
 class gr_simple_correlator;
 class gr_simple_framer;
 class gr_simple_squelch_cc;
+class gr_single_pole_iir_filter_cc;
 class gr_single_pole_iir_filter_ff;
+class gr_skiphead;
 class gr_stream_to_streams;
+class gr_stream_to_vector;
 class gr_streams_to_stream;
 class gr_streams_to_vector;
 class gr_sub_cc;
@@ -164,6 +180,8 @@ class gr_sync_decimator;
 class gr_sync_interpolator;
 class gr_threshold_ff;
 class gr_throttle;
+class gr_uchar_to_float;
+class gr_unpacked_to_packed_bb;
 class gr_vco_f;
 class gr_vector_sink_b;
 class gr_vector_sink_c;
@@ -175,7 +193,10 @@ class gr_vector_source_c;
 class gr_vector_source_f;
 class gr_vector_source_i;
 class gr_vector_source_s;
+class gr_vector_to_stream;
 class gr_vector_to_streams;
+class gri_agc;
+class gri_agc_cc;
 class microtune_4702_eval_board;
 class microtune_4937_eval_board;
 class microtune_xxxx_eval_board;
