@@ -1,5 +1,5 @@
 #
-# Copyright 2003,2004 Free Software Foundation, Inc.
+# Copyright 2003,2004,2006 Free Software Foundation, Inc.
 # 
 # This file is part of GNU Radio
 # 
@@ -30,6 +30,11 @@ from flow_graph import *
 from exceptions import *
 from hier_block import *
 
+
 # create a couple of aliases
-stream_to_vector = serial_to_parallel
-vector_to_stream = parallel_to_serial
+serial_to_parallel = stream_to_vector
+parallel_to_serial = vector_to_stream
+
+# Force the preference database to be initialized
+from prefs import prefs
+
